summaryrefslogtreecommitdiffstats
path: root/src/kvirc/kernel/kvi_irclink.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kvirc/kernel/kvi_irclink.cpp')
-rw-r--r--src/kvirc/kernel/kvi_irclink.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/kvirc/kernel/kvi_irclink.cpp b/src/kvirc/kernel/kvi_irclink.cpp
index 8c79507c..132da95e 100644
--- a/src/kvirc/kernel/kvi_irclink.cpp
+++ b/src/kvirc/kernel/kvi_irclink.cpp
@@ -50,7 +50,7 @@
#define __KVI_DEBUG__
#include "kvi_debug.h"
-#include <qtimer.h>
+#include <tqtimer.h>
extern KVIRC_API KviIrcServerDataBase * g_pIrcServerDataBase;
extern KVIRC_API KviProxyDataBase * g_pProxyDataBase;
@@ -59,7 +59,7 @@ extern KVIRC_API KviGarbageCollector * g_pGarbageCollector;
KviIrcLink::KviIrcLink(KviIrcConnection * pConnection)
-: QObject()
+: TQObject()
{
m_pConnection = pConnection;
m_pTarget = pConnection->target();
@@ -105,7 +105,7 @@ void KviIrcLink::destroySocket()
{
if(m_pLinkFilter)
{
- QObject::disconnect(m_pLinkFilter,0,this,0);
+ TQObject::disconnect(m_pLinkFilter,0,this,0);
// the module extension server links must be destroyed in the module that provided it
m_pLinkFilter->die();
m_pLinkFilter = 0;
@@ -118,7 +118,7 @@ void KviIrcLink::destroySocket()
}
}
-void KviIrcLink::createSocket(const QString &szLinkFilterName)
+void KviIrcLink::createSocket(const TQString &szLinkFilterName)
{
destroySocket(); // make sure we do not leak memory
@@ -126,14 +126,14 @@ void KviIrcLink::createSocket(const QString &szLinkFilterName)
if(szLinkFilterName.isEmpty())return;
- if(KviQString::equalCI(szLinkFilterName,"irc"))return;
+ if(KviTQString::equalCI(szLinkFilterName,"irc"))return;
m_pLinkFilter = (KviMexLinkFilter *)g_pModuleExtensionManager->allocateExtension("linkfilter",
szLinkFilterName.utf8().data(),m_pConsole,0,this,szLinkFilterName.utf8().data());
if(m_pLinkFilter)
{
- connect(m_pLinkFilter,SIGNAL(destroyed()),this,SLOT(linkFilterDestroyed()));
+ connect(m_pLinkFilter,TQT_SIGNAL(destroyed()),this,TQT_SLOT(linkFilterDestroyed()));
m_pConsole->output(KVI_OUT_SYSTEMMESSAGE,
__tr2qs("Using filtered IRC protocol: Link filter is \"%Q\""),&szLinkFilterName);
return;
@@ -167,7 +167,7 @@ void KviIrcLink::start()
m_eState = Connecting;
if(m_pResolver)delete m_pResolver; // this should never happen
m_pResolver = new KviIrcConnectionTargetResolver(m_pConnection);
- connect(m_pResolver,SIGNAL(terminated()),this,SLOT(resolverTerminated()));
+ connect(m_pResolver,TQT_SIGNAL(terminated()),this,TQT_SLOT(resolverTerminated()));
m_pResolver->start(m_pTarget);
}
@@ -197,7 +197,7 @@ void KviIrcLink::resolverTerminated()
if(iErr != KviError_success)
{
- QString strDescription(KviError::getDescription(iErr));
+ TQString strDescription(KviError::getDescription(iErr));
m_pConsole->output(KVI_OUT_SYSTEMERROR,
__tr2qs("Failed to start the connection: %Q"),
&strDescription);
@@ -276,7 +276,7 @@ void KviIrcLink::processData(char * buffer,int len)
// handler event that disconnects explicitly)
//
// We handle it by simply returning control to readData() which
// will return immediately (and safely) control to Qt
kvi_free(messageBuffer);
return;
}
@@ -276,7 +276,7 @@ void KviIrcLink::processData(char * buffer,int len)
//
// We handle it by simply returning control to readData() which
- // will return immediately (and safely) control to Qt
+ // will return immediately (and safely) control to TQt
kvi_free(messageBuffer);
return;